@@ -9,7 +9,10 @@
 #
 
 package Config::Model::Xorg ;
-$Config::Model::Xorg::VERSION = '1.114';
+$Config::Model::Xorg::VERSION = '1.115';
+use 5.10.1;
+use Config::Model 2.123;
+
 # dummy package so CPAN can collect information regarding this module
 
 
@@ -19,7 +22,7 @@ Config::Model::Xorg - Xorg configuration model for Config::Model
 
 =head1 VERSION
 
-version 1.114
+version 1.115
 
 =head1 SYNOPSIS
 
